@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.h,v 1.10 2008/10/05 06:02:51 bowkenken Exp $
+* $Id: GameMusic.h,v 1.13 2009/01/04 00:26:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GAME_MUSIC_H
@@ -97,10 +97,12 @@ public:
 	~GameMusic();
 	void init();
 	void initLsMusic( LsMusic *ls, WSCstring dir );
+	void close();
 
 	void playScene();
 	void playLastScene();
 	void play( music_kind_t kind, long idx = -1 );
+	void replayPrev();
 	void replay();
 	WSCstring playTitle( long idx );
 	WSCstring playGameOver( long idx );
