@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.h,v 1.29 2008/09/25 06:47:46 bowkenken Exp $
+* $Id: GlobalVar.h,v 1.32 2009/02/14 04:44:02 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GLOBAL_VAR_H
@@ -61,12 +61,14 @@ typedef long GtkButton;
 #include "GuiWords.h"
 #include "GuiReplay.h"
 #include "GuiClassEdit.h"
+#include "GuiSkillEdit.h"
 #include "GuiChrSheet.h"
 #include "SelMbrGraph.h"
 #include "WinPos.h"
 #include "FileList.h"
 #include "PcgDun.h"
 #include "GameMusic.h"
+#include "GameSound.h"
 #include "GameJoystick.h"
 #include "Key.h"
 #include "MouseMotion.h"
@@ -114,6 +116,9 @@ extern GuiReplay gGuiReplay;
 // 饹ǥɥ
 extern GuiClassEdit gGuiClassEdit;
 
+// 롦ǥɥ
+extern GuiSkillEdit gGuiSkillEdit;
+
 // 饯ȡɥ
 extern GuiChrSheet gGuiChrSheet;
 
@@ -129,6 +134,9 @@ extern PcgDun gPcgDun;
 // BGM δ
 extern GameMusic gMusic;
 
+// SE δ
+extern GameSound gSound;
+
 // 祤ƥåδ
 extern GameJoystick gJoystick;
 
