@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.82 2008/09/21 13:00:03 bowkenken Exp $
+* $Id: amenu.c,v 1.85 2009/02/19 03:42:08 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1049,7 +1049,7 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 		clr_chr_trgt_act( mbr, TRUE );
 
 	macro = ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n].macro;
-	set_key_buf_str( macro );
+	set_key_buf_str_head( macro );
 
 	return TRUE;
 }
@@ -2417,7 +2417,6 @@ char	*cb_menu_auto_mark_edit_macro_reg_macro(
 	/* ǧ */
 
 	msg = MSG_TTL_MENU_AUTO_MARK_EDIT_MACRO_REG_MACRO;
-	print_msg( FLG_NULL, msg );
 
 	ask = exec_menu_ask( msg, ASK_NO, TRUE );
 	if( ask == ASK_ERR )
