@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.11 2008/09/10 23:09:58 bowkenken Exp $
+* $Id: gf-conf.c,v 1.16 2009/02/14 04:43:41 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -338,6 +338,9 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "multiple_message_line" ) == 0 ){
 		return load_game_conf_mul_line( id, val );
 
+	} else if( strcmp( id, "joystick_number" ) == 0 ){
+		return load_game_conf_joystick_number( id, val );
+
 	} else if( strcmp( id, "vfx_member_cure" ) == 0 ){
 		return load_game_conf_vfx_mbr( FLG_VFX_MBR_CURE, val );
 
@@ -419,6 +422,9 @@ bool_t	load_game_conf_set_str(
 	} else if( strcmp( id, "scroll" ) == 0 ){
 		return load_game_conf_scroll( id, str );
 
+	} else if( strcmp( id, "joystick_type" ) == 0 ){
+		return load_game_conf_joystick_kind( id, str );
+
 	} else if( strcmp( id, "color" ) == 0 ){
 		return load_game_conf_color_name( id, str );
 
@@ -602,6 +608,23 @@ bool_t	load_game_conf_scroll( char *id, char *str )
 	return TRUE;
 }
 
+/***************************************************************
+* 祤ƥåμ
+* char *id : ̻
+* char *str : 祤ƥåμ̾
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_joystick_kind( char *id, char *str )
+{
+	joy_kind_t	k;
+
+	k = cv_joystick_name_to_kind( str );
+	call_game_joystick_set_kind( k );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եξ˥Хåե򥯥ꥢ뤫
 * char *id : ̻
@@ -672,6 +695,20 @@ bool_t	load_game_conf_mul_line( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* 祤ƥåֹ
+* char *id : ̻
+* long val : 祤ƥåֹ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_joystick_number( char *id, long val )
+{
+	call_game_joystick_sel_joy( (joy_kind_t)val );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥɥ֤
 * char *id : ̻
@@ -845,6 +882,14 @@ bool_t	load_game_conf_color_name( char *id, char *name )
 		g_crnt_attr_n = CURS_ATTR_N_MBR_5;
 	if( strcmp( name, "mbr_6" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MBR_6;
+	if( strcmp( name, "heat" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_HEAT;
+	if( strcmp( name, "cold" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_COLD;
+	if( strcmp( name, "mind" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MIND;
+	if( strcmp( name, "acid" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_ACID;
 
 	return TRUE;
 }
@@ -1567,6 +1612,7 @@ bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver )
 	flg_err |= !save_game_conf_scroll( fp, ver );
 	flg_err |= !save_game_conf_flg( fp, ver );
 	flg_err |= !save_game_conf_win_pos( fp, ver );
+	flg_err |= !save_game_conf_joystick( fp, ver );
 	flg_err |= !save_game_conf_vfx( fp, ver );
 	flg_err |= !save_game_conf_color( fp, ver );
 	flg_err |= !save_game_conf_key_tab( fp, ver );
@@ -1769,6 +1815,39 @@ bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥ祤ƥåΥ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_joystick( FILE *fp, const ver_t *ver )
+{
+	long	n;
+	joy_kind_t	kind;
+	const char	*name;
+
+	if( fp == NULL )
+		return FALSE;
+	if( ver == NULL )
+		return FALSE;
+
+	fprintf( fp, "\n" );
+	fprintf( fp, "# joystick\n" );
+	fprintf( fp, "\n" );
+
+	n = call_game_joystick_get_joy();
+	kind = (joy_kind_t)call_game_joystick_get_kind();
+	name = cv_joystick_kind_to_name( kind );
+
+	fprintf( fp, "joystick_number = %ld\n", (long)n );
+	fprintf( fp, "joystick_type = \"%s\"\n", name );
+	fprintf( fp, "\n" );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եλи̤Υ
 * FILE *fp : ե
@@ -1888,6 +1967,14 @@ bool_t	save_game_conf_color( FILE *fp, const ver_t *ver )
 			CURS_ATTR_N_MBR_5 );
 	save_game_conf_color_sub( fp, "mbr_6",
 			CURS_ATTR_N_MBR_6 );
+	save_game_conf_color_sub( fp, "heat",
+			CURS_ATTR_N_HEAT );
+	save_game_conf_color_sub( fp, "cold",
+			CURS_ATTR_N_COLD );
+	save_game_conf_color_sub( fp, "mind",
+			CURS_ATTR_N_MIND );
+	save_game_conf_color_sub( fp, "acid",
+			CURS_ATTR_N_ACID );
 
 	return TRUE;
 }
@@ -2130,7 +2217,7 @@ void	back_up_game_conf( void )
 /***************************************************************
 * ɥ֤̾
 * win_kind_t k : ɥμ
-* return : 
+* return : ɥ̾
 ***************************************************************/
 
 const char	*get_win_kind_name( win_kind_t k )
@@ -2170,6 +2257,8 @@ const char	*get_win_kind_name( win_kind_t k )
 		return "window_replay";
 	case WIN_KIND_CLASS_EDIT:
 		return "window_class_edit";
+	case WIN_KIND_SKILL_EDIT:
+		return "window_skill_edit";
 	case WIN_KIND_CHR_SHEET:
 		return "window_character_sheet";
 	case WIN_KIND_MAX_N:
@@ -2179,6 +2268,51 @@ const char	*get_win_kind_name( win_kind_t k )
 	return NULL;
 }
 
+/***************************************************************
+* 祤ƥåμफ饸祤ƥåμ̾Ѵ
+* joy_kind_t k : 祤ƥåμ
+* return : 祤ƥåμ̾
+***************************************************************/
+
+const char	*cv_joystick_kind_to_name( joy_kind_t k )
+{
+	switch( k ){
+	case JOY_KIND_NULL:
+		break;
+	case JOY_KIND_PS:
+		return "ps like";
+	case JOY_KIND_SATURN:
+		return "saturn like";
+	case JOY_KIND_RAP3:
+		return "real arcade pro.3";
+	case JOY_KIND_MAX_N:
+		break;
+	}
+
+	return "ps-like";
+}
+
+/***************************************************************
+* 祤ƥåμ̾饸祤ƥåμѴ
+* const char *name : 祤ƥåμ̾
+* return : 祤ƥåμ
+***************************************************************/
+
+joy_kind_t	cv_joystick_name_to_kind( const char *name )
+{
+	if( name == NULL )
+		return JOY_KIND_PS;
+
+	if( strcmp( name, "ps like" ) == 0 )
+		return JOY_KIND_PS;
+	if( strcmp( name, "saturn like" ) == 0 )
+		return JOY_KIND_SATURN;
+	if( strcmp( name, "real arcade pro.3" ) == 0 )
+		return JOY_KIND_RAP3;
+
+	return JOY_KIND_PS;
+}
+
 /***************************************************************
 * ֹ椫鿧ʸѴ
 * int color : ֹ
