@@ -73,13 +73,14 @@ static struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUT:D:S:l:k:e:s:p:md:Vvh"
+#define	STR_OPT	"GCUN:T:D:S:l:k:e:s:p:md:Vvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
 	{ "gui",           no_argument,       NULL, 'G' },
 	{ "cui",           no_argument,       NULL, 'C' },
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
+	{ "gnome",         required_argument, NULL, 'N' },
 	{ "text-mode",     required_argument, NULL, 'T' },
 	{ "sel-graph-dir", required_argument, NULL, 'D' },
 	{ "map-scale",     required_argument, NULL, 'S' },
@@ -106,6 +107,8 @@ char	str_usage[] = {
 	"  -G, --gui                set GUI mode\n"
 	"  -C, --cui                set CUI mode\n"
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
+	"  -N, --gnome              window manager is GNOME\n"
+	"                             ON or OFF\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -T, --text-mode=POINT    set TEXT mode:\n"
 	"                             point of font, ON or OFF\n"
@@ -353,6 +356,8 @@ void	init_arg( void )
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
 
+	g_flg_gnome = TRUE;
+
 	g_flg_text_mode = FALSE;
 	g_text_mode_point = 0;
 
@@ -432,6 +437,9 @@ void	chk_arg( int argc, char **argv )
 			g_flg_cui = TRUE;
 			g_flg_gui = TRUE;
 			break;
+		case 'N':
+			chk_opt_flg( optarg, &g_flg_gnome, TRUE );
+			break;
 		case 'T':
 			if( chk_opt_flg( optarg, &g_flg_text_mode,
 					FALSE ) ){
