@@ -148,6 +148,9 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
+/* ɥޥ͡㤬 GNOME? */
+EXTERN bool_t	g_flg_gnome;
+
 /* GUI Υƥɽ⡼ */
 EXTERN bool_t	g_flg_text_mode;
 
