@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.26 2008/09/07 11:31:57 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.30 2009/02/09 08:08:09 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -63,11 +63,7 @@ int	main_dows( int argc, char **argv )
 #else
 	g_flg_cui = FALSE;
 #endif
-#if 1
-//@@@
-	g_flg_gui = TRUE;
-	g_flg_cui = TRUE;
-#endif
+	g_flg_cui = FALSE;
 
 	chk_arg( argc, argv );
 
@@ -90,6 +86,8 @@ int	main_dows( int argc, char **argv )
 		}
 
 		gMusic.init();
+		gSound.init();
+		gJoystick.init();
 
 		// ȥ
 
@@ -130,6 +128,16 @@ void	init_main_sel_conf( void *cnf )
 		exit_game( EXIT_FAILURE );
 }
 
+////////////////////////////////////////////////////////////////
+// ཪλν
+////////////////////////////////////////////////////////////////
+
+void	closeGameGui()
+{
+	gSound.close();
+	gMusic.close();
+}
+
 ////////////////////////////////////////////////////////////////
 // ơС˥åɽ
 // const char *s : եޥåʸ
@@ -164,6 +172,8 @@ void	gexit( long code )
 	else
 		gFlagExit = true;
 
+	closeGameGui();
+
 	theApp.m_pMainFrm->PostMessage(
 			WM_CLOSE, (WPARAM)code, (LPARAM)code );
 
