@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.198 2008/09/09 12:32:55 bowkenken Exp $
+* $Id: mnstr.c,v 1.218 2009/03/10 16:18:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -68,6 +68,9 @@ static mnstr_t	mnstr_used;
 /* ̤ */
 static mnstr_t	mnstr_free;
 
+/* 饹ܥ */
+static mnstr_t	*g_last_boss[LAST_BOSS_KIND_MAX_N];
+
 /***************************************************************
 * 󥹥Υǡơ֥
 ***************************************************************/
@@ -148,6 +151,16 @@ void	init_mnstr( void )
 		ls_flg_chk_mnstr_kind[mnstr_boss_lev_tab[i].kind] = TRUE;
 	}
 
+	// 饹ܥå
+
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( mnstr_last_boss_lev_tab[i].kind == MNSTR_KIND_NULL )
+			break;
+
+		ls_flg_chk_mnstr_kind[mnstr_last_boss_lev_tab[i].kind]
+				= TRUE;
+	}
+
 	// ʣå
 
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
@@ -167,7 +180,7 @@ void	init_mnstr( void )
 
 	for( i = MNSTR_KIND_NULL + 1; i < MNSTR_KIND_MAX_N; i++ ){
 		if( !ls_flg_chk_mnstr_kind[i] ){
-			name = get_mnstr_name( i );
+			name = get_mnstr_name( (mnstr_kind_t)i );
 			print_msg( FLG_MSG_DEBUG,
 					MSG_ERR_MNSTR_LEV_TAB_NOT_DEF,
 					name );
@@ -193,9 +206,16 @@ void	init_mnstr( void )
 		}
 	}
 
+	for( i = 0; i < LAST_BOSS_KIND_MAX_N; i++ )
+		g_last_boss[i] = NULL;
+
 	reset_mnstr();
 }
 
+/***************************************************************
+* 󥹥Υ٥롦ơ֥
+***************************************************************/
+
 void	init_mnstr_lev_tab( mnstr_lev_tab_t stage[], long *n )
 {
 	long	i;
@@ -333,6 +353,17 @@ void	new_mnstr( mnstr_t *mnstr )
 		mnstr->abl.lev[i].add = 0;
 		mnstr->abl.exp[i].n = mnstr->abl.exp[i].max;
 	}
+	for( ; i < ABL_SKILL_MAX_N; i++ ){
+		lev = 0;
+
+		mnstr->abl.lev[i].max = lev;
+		mnstr->abl.exp[i].max = calc_lev_to_exp(
+				lev, (abl_kind_t)i );
+
+		mnstr->abl.lev[i].n = mnstr->abl.lev[i].max;
+		mnstr->abl.lev[i].add = 0;
+		mnstr->abl.exp[i].n = mnstr->abl.exp[i].max;
+	}
 	mnstr->abl.hp.max = calc_max_hp( mnstr );
 	mnstr->abl.mp.max = calc_max_mp( mnstr );
 	mnstr->abl.hp.n = mnstr->abl.hp.max;
@@ -395,6 +426,8 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->flg_pet = FALSE;
 
 	mnstr->work.flg = FLG_NULL;
+	mnstr->work.hyper_boss = HYPER_BOSS_NULL;
+	mnstr->work.flg_hyper_boss = FALSE;
 	mnstr->work.caught = 0;
 	mnstr->work.catch_chr = NULL;
 	mnstr->work.link_chr = NULL;
@@ -706,6 +739,26 @@ bool_t	make_mnstr_special( mnstr_t *p, long dun_lev )
 			break;
 		}
 
+		break;
+	case MNSTR_KIND_EXEL:
+		g_last_boss[LAST_BOSS_KIND_EXEL] = p;
+
+		p->flg_chr |= FLG_CHR_HYPER;
+		p->work.hyper_boss = HYPER_BOSS_NORMAL;
+		p->work.flg_hyper_boss = FALSE;
+		break;
+	case MNSTR_KIND_EXELER:
+		g_last_boss[LAST_BOSS_KIND_EXELER] = p;
+
+		p->flg_chr |= FLG_CHR_HYPER;
+		p->work.hyper_boss = HYPER_BOSS_NORMAL;
+		p->work.flg_hyper_boss = FALSE;
+		break;
+	case MNSTR_KIND_XEX:
+		g_last_boss[LAST_BOSS_KIND_XEX] = p;
+		break;
+	case MNSTR_KIND_XX:
+		g_last_boss[LAST_BOSS_KIND_XX] = p;
 		break;
 	}
 
@@ -1300,21 +1353,23 @@ bool_t	chk_auto_door_mnstr( mnstr_t *p, long x1, long y1, long x2, long y2 )
 bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y )
 {
 	dun_t	*dun = get_dun();
+	door_t	*dr;
 
 	if( p == NULL )
 		return FALSE;
 	if( !clip_pos( x, y ) )
 		return FALSE;
 
-	if( dun->map.obj.mjr[y][x] == FACE_MJR_DOOR_CLOSE ){
-		door_t	*dr;
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_DOOR_CLOSE )
+		return FALSE;
+	if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_LOOK_WALL ) )
+		return FALSE;
 
-		dr = get_door( x, y );
-		if( dr != NULL )
-			return chr_open_door( p, dr->n );
-	}
+	dr = get_door( x, y );
+	if( dr == NULL )
+		return FALSE;
 
-	return FALSE;
+	return chr_open_door( p, dr->n );
 }
 
 /***************************************************************
@@ -1328,23 +1383,23 @@ bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y )
 bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y )
 {
 	dun_t	*dun = get_dun();
-	char	c;
+	door_t	*dr;
 
 	if( p == NULL )
 		return FALSE;
 	if( !clip_pos( x, y ) )
 		return FALSE;
 
-	c = dun->map.obj.mjr[y][x];
-	if( (c == FACE_MJR_DOOR_CLOSE) || (c == FACE_MJR_DOOR_OPEN) ){
-		door_t	*dr;
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_DOOR_CLOSE )
+		return FALSE;
+	if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_LOOK_WALL ) )
+		return FALSE;
 
-		dr = get_door( x, y );
-		if( dr != NULL )
-			return chr_break_door( p, dr->n );
-	}
+	dr = get_door( x, y );
+	if( dr == NULL )
+		return FALSE;
 
-	return FALSE;
+	return chr_break_door( p, dr->n );
 }
 
 /***************************************************************
@@ -1377,6 +1432,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	dun_t	*dun;
 	party_t	*pty;
 	bool_t	flg_pre_find;
+	flg_map_t	flg;
 	long	bx, by;
 	long	ex, ey;
 	long	x, y;
@@ -1393,6 +1449,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 
 	flg_pre_find = chk_flg( p->flg_map, FLG_MAP_CHR_FIND );
 	p->flg_map &= ~FLG_MAP_CHR_FIND;
+	flg = FLG_NULL;
 	for( i = 0; i < MBR_MAX_N; i++ ){
 
 		/* ȯ? */
@@ -1400,6 +1457,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 
 			/* ȯޥåסե饰ΩƤ */
 			p->flg_map |= FLG_MAP_CHR_FIND;
+			flg = FLG_MAP_CHR_FIND;
 
 			break;
 		}
@@ -1423,7 +1481,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 			if( !clip_pos( x, y ) )
 				continue;
 
-				dun->map.chr.flg[y][x] = p->flg_map;
+				dun->map.chr.flg[y][x] |= flg;
 		}
 	}
 
@@ -1484,6 +1542,9 @@ void	chk_boss_find_mbr( mnstr_t *p )
 	curs_attrset_chr( p, +1, TRUE );
 	print_msg( FLG_NULL, MSG_BOSS_FIND_MBR, p->name );
 	curs_attrset_dflt();
+
+	draw_words( NULL, MSG_BOSS_FIND_MBR, p->name );
+	redraw_all();
 }
 
 /***************************************************************
@@ -1595,9 +1656,16 @@ void	die_boss( mnstr_t *m )
 	}
 
 	if( boss_n <= 1 ){
-		/* ܥݤ鳬ʤ */
+		/* å */
+		draw_words( NULL, MSG_FIGHT_KILL_BOSS, m->name );
 
+		/* ܥݤ鳬ʤ */
 		make_stairs( m->x, m->y, FACE_MJR_STAIRS_DOWN );
+
+		/* ƥ */
+		mnstr_drop_key_item( p );
+
+		redraw_all();
 	}
 }
 
@@ -1733,6 +1801,41 @@ void	mnstr_drop_item( mnstr_t *p )
 	}
 }
 
+/***************************************************************
+* ܥ󥹥˥ƥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	mnstr_drop_key_item( mnstr_t *p )
+{
+	dun_t	*dun = get_dun();
+	star_drop_kind_t	kind;
+	static char	str[SCREEN_WIDTH * 8 + 1];
+	const long	max_len = SCREEN_WIDTH * 8;
+
+	if( p == NULL )
+		return;
+	if( p->mnstr_tab == NULL )
+		return;
+
+	kind = (star_drop_kind_t)
+			(labs( dun->lev ) / DUN_LEV_BOSS - 1);
+	kind = (star_drop_kind_t)
+			((kind + BOOT_UNIT_MAX_N) % BOOT_UNIT_MAX_N);
+
+	if( chk_key_item( kind ) )
+		return;
+
+	set_key_item( kind, TRUE );
+
+	sn_printf( str, max_len, MSG_GET_KEY_ITEM,
+			get_key_item_name( kind ) );
+
+	print_msg( FLG_NULL, MSG_S, str );
+	draw_words( NULL, str );
+	redraw_all();
+}
+
 /***************************************************************
 * ƤΥ󥹥ȯȲĻξ֤ˤ
 ***************************************************************/
@@ -2101,6 +2204,9 @@ mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 	mnstr_lev_tab_t	*tab;
 	long	i, max_i, n;
 
+	if( mnstr_kind == MNSTR_KIND_NULL )
+		return NULL;
+
 	tab = NULL;
 	n = 0;
 	max_i = sizeof( mnstr_lev_tab ) / sizeof( mnstr_lev_tab[0] );
@@ -2163,80 +2269,6 @@ void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 	ls->prev = p;
 }
 
-/***************************************************************
-* 󥹥˷иͤͿ
-* chr_t *chr : 󥹥
-* long exp : и
-* bool_t flg_print_lev : ٥Υåɽ뤫
-***************************************************************/
-
-void	exp_chr_mnstr(
-	chr_t *chr,
-	long exp,
-	bool_t flg_set_max,
-	bool_t flg_print_lev
-)
-{
-	long	left_exp;
-	rate_t	abl_sum;
-	long	left_k, k;
-	long	left_n;
-
-	if( chr == NULL )
-		return;
-	if( chr->mnstr_tab == NULL )
-		return;
-
-	left_exp = exp;
-	left_n = 0;
-	left_k = 0;
-
-	abl_sum = 0;
-	for( k = 0; k < ABL_KIND_MAX_N; k++ )
-		abl_sum += chr->mnstr_tab->abl_lev_rate[k];
-	if( abl_sum <= 0 )
-		return;
-
-	for( k = 0; k < ABL_KIND_MAX_N; k++ ){
-		rate_t	abl_rate;
-		long	e;
-
-		abl_rate = chr->mnstr_tab->abl_lev_rate[k];
-		if( abl_rate == 0 )
-			continue;
-
-		e = exp * abl_rate / abl_sum;
-		chr->abl.exp[k].n += e;
-
-		if( chr->abl.exp[k].n < 0 )
-			chr->abl.exp[k].n = 0;
-		if( chr->abl.exp[k].n > EXP_MAX )
-			chr->abl.exp[k].n = EXP_MAX;
-		if( flg_set_max )
-			chr->abl.exp[k].max = chr->abl.exp[k].n;
-		if( chr->abl.exp[k].max < chr->abl.exp[k].n )
-			chr->abl.exp[k].max = chr->abl.exp[k].n;
-
-		left_exp -= e;
-		left_n++;
-		if( per_randm( left_n ) )
-			left_k = k;
-	}
-
-	chr->abl.exp[left_k].n += left_exp;
-
-	if( chr->abl.exp[left_k].n < 0 )
-		chr->abl.exp[left_k].n = 0;
-	if( chr->abl.exp[left_k].n > EXP_MAX )
-		chr->abl.exp[left_k].n = EXP_MAX;
-	if( flg_set_max )
-		chr->abl.exp[left_k].max = chr->abl.exp[left_k].n;
-	if( chr->abl.exp[left_k].max < chr->abl.exp[left_k].n )
-		chr->abl.exp[left_k].max = chr->abl.exp[left_k].n;
-
-	chk_lev_up( chr, FALSE, flg_print_lev );
-}
-
 /***************************************************************
 * 󥹥ݤηиͤ׻
 * 󥹥Υ٥Υ롼פθ
@@ -2451,6 +2483,11 @@ mnstr_t	*get_mnstr( long x, long y )
 	if( pet != NULL )
 		return pet;
 
+	/* 饹ܥĴ٤ */
+
+	if( chk_xx_pos( x, y ) )
+		return get_last_boss( LAST_BOSS_KIND_XX );
+
 	return NULL;
 }
 
@@ -2897,6 +2934,17 @@ mnstr_kind_t	get_mnstr_kind_from_face( char mjr, char mnr )
 	return k;
 }
 
+/***************************************************************
+* 饹ܥ֤
+* last_boss_kind_t kind : 饹ܥμ
+* return : 饹ܥ
+***************************************************************/
+
+mnstr_t	*get_last_boss( last_boss_kind_t kind )
+{
+	return g_last_boss[kind];
+}
+
 /***************************************************************
 * 󥹥γƺѥ꡼ꥹȤ֤
 * return : 󥹥Υ꡼ꥹ
