@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.213 2008/09/21 00:58:16 bowkenken Exp $
+* $Id: party.c,v 1.227 2009/03/10 10:33:45 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -33,6 +33,10 @@
 
 /**/
 
+#define	FLG_NICOTINE_TEST	0
+
+/**/
+
 #define	DFLT_EXP	500
 #define	DFLT_GOLD	3000
 
@@ -533,13 +537,24 @@ void	init_party_debug( void )
 	i = 0;
 	sub_kind.wpn = WPN_KIND_GREAT_SWORD;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
-			TRUE, FALSE, TRUE );
+			TRUE, FALSE, FALSE );
 
 	i = 0;
 	sub_kind.wpn = WPN_KIND_GLAIVE;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
+			TRUE, FALSE, FALSE );
+
+	i = 0;
+	sub_kind.wpn = WPN_KIND_KATANA;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
 			TRUE, FALSE, TRUE );
 
+	i = 0;
+	sub_kind.wpn = WPN_KIND_WAKIZASHI;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
+			TRUE, FALSE, FALSE );
+	equip_item( ls_mbr[i], item, EQUIP_KIND_SHIELD );
+
 	i = 1;
 	sub_kind.wpn = WPN_KIND_GREAT_AXE;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
@@ -921,12 +936,11 @@ void	init_party_debug( void )
 
 	/**/
 
-#if	0
-/*@@@*/
-	i = 0;
-	ls_mbr[i]->fx_data.nicotine.poisoning_rate = _100_PERCENT;
-	ls_mbr[i]->fx_data.nicotine.lost_rate = _100_PERCENT;
-#endif
+	if( FLG_NICOTINE_TEST ){
+		i = 0;
+		ls_mbr[i]->fx_data.nicotine.poisoning_rate = _100_PERCENT;
+		ls_mbr[i]->fx_data.nicotine.lost_rate = _100_PERCENT;
+	}
 }
 
 /**/
@@ -1253,6 +1267,17 @@ void	new_mbr(
 		mbr->abl.lev[i].add = 0;
 		mbr->abl.exp[i].n = mbr->abl.exp[i].max;
 	}
+	for( ; i < ABL_SKILL_MAX_N; i++ ){
+		lev = 0;
+
+		mbr->abl.lev[i].max = lev;
+		mbr->abl.exp[i].max = calc_lev_to_exp(
+				lev, (abl_kind_t)i );
+
+		mbr->abl.lev[i].n = mbr->abl.lev[i].max;
+		mbr->abl.lev[i].add = 0;
+		mbr->abl.exp[i].n = mbr->abl.exp[i].max;
+	}
 	mbr->abl.hp.max = calc_max_hp( mbr );
 	mbr->abl.mp.max = calc_max_mp( mbr );
 	mbr->abl.hp.n = mbr->abl.hp.max;
@@ -1317,6 +1342,8 @@ void	new_mbr(
 	mbr->mnstr_tab = NULL;
 
 	mbr->work.flg = FLG_NULL;
+	mbr->work.hyper_boss = HYPER_BOSS_NULL;
+	mbr->work.flg_hyper_boss = FALSE;
 	mbr->work.caught = 0;
 	mbr->work.catch_chr = NULL;
 	mbr->work.link_chr = NULL;
@@ -1431,7 +1458,9 @@ void	set_mbr_dir( void )
 	}
 }
 
-/**/
+/***************************************************************
+* Сޥåפ˽и
+***************************************************************/
 
 void	appear_party( void )
 {
@@ -1468,7 +1497,10 @@ void	appear_party( void )
 	redraw_all();
 }
 
-/**/
+/***************************************************************
+* Сޥåפ˽и ()
+* return : ?
+***************************************************************/
 
 bool_t	appear_party_randm( void )
 {
@@ -1511,6 +1543,11 @@ bool_t	appear_party_randm( void )
 	return FALSE;
 }
 
+/***************************************************************
+* Сޥåפ˽и (򥵡)
+* return : ?
+***************************************************************/
+
 bool_t	appear_party_srch( void )
 {
 	long	randm_x, randm_y;
@@ -1573,6 +1610,10 @@ bool_t	appear_party_srch( void )
 	return FALSE;
 }
 
+/***************************************************************
+* Сޥåפ˽и (Ū)
+***************************************************************/
+
 void	appear_party_force( void )
 {
 	long	x, y;
@@ -1587,13 +1628,80 @@ void	appear_party_force( void )
 	party.square.pre_y = party.square.y;
 
 	for( n = 0; n < MBR_MAX_N; n++ ){
-		party.mbr[n]->x = MAP_DEL_X;
-		party.mbr[n]->y = MAP_DEL_Y;
+		if( chk_flg_or( party.mbr[n]->stat,
+				FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD ) ){
+			continue;
+		}
 
 		put_chr( party.mbr[n], x, y );
 	}
 }
 
+/***************************************************************
+* Сޥåפ˽и (饹ܥ)
+***************************************************************/
+
+void	appear_party_last_boss( void )
+{
+	appear_party_map_event( MAP_EVENT_LAST_BOSS_APPEAR_PARTY );
+}
+
+/***************************************************************
+* Сޥåפ˽и (ޥåס٥Ȱ)
+* char mnr : ޥåס٥ȼʸ
+***************************************************************/
+
+void	appear_party_map_event( char mnr )
+{
+	pos_t	pos;
+	long	x, y;
+	long	n;
+
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		lost_trgt( party.mbr[n] );
+		clr_chr_trgt_act( party.mbr[n], FALSE );
+	}
+
+	release_all_mbr();
+	clr_map_all_mbr();
+
+	pos = get_map_event_pos( mnr );
+	x = pos.x;
+	y = pos.y;
+
+	party.square.x = x;
+	party.square.y = y;
+	party.square.pre_x = party.square.x;
+	party.square.pre_y = party.square.y;
+
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		long	nx, ny;
+
+		if( chk_flg_or( party.mbr[n]->stat,
+				FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD ) ){
+			continue;
+		}
+
+		nx = party.square.x + party.square.chr_pos[n].x;
+		ny = party.square.y + party.square.chr_pos[n].y;
+
+		party.mbr[n]->x = MAP_DEL_X;
+		party.mbr[n]->y = MAP_DEL_Y;
+
+		put_chr( party.mbr[n], nx, ny );
+	}
+
+	appear_all_pet();
+
+	next_pos_square( 0 );
+	scroll_center_appear_party();
+	set_flg_find_all_mnstr();
+
+	redraw_all();
+}
+
 /***************************************************************
 * Сߤꤿֿ
 * return : ֿ
@@ -1621,9 +1729,22 @@ long	get_party_dun_max_lev( void )
 
 void	scroll_center_appear_party( void )
 {
+	pos_t	*draw;
+	pos_t	*draw_gui;
+
 	if( chk_flg_or( get_flg_scroll(),
 			(FLG_SCROLL_CENTER | FLG_SCROLL_SMOOTH) ) ){
 		scroll_center();
+	} else {
+		scroll_half_page();
+	}
+
+	draw = get_map_draw_pos();
+	draw_gui = get_map_draw_pos_gui();
+	if( (draw != NULL) && (draw_gui != NULL) ){
+		draw_gui->x = draw->x;
+		draw_gui->y = draw->y;
+		call_pcg_dun_scroll( draw_gui->x, draw_gui->y );
 	}
 }
 
@@ -1796,6 +1917,18 @@ bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 )
 /**/
 
 bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 )
+{
+	if( chk_auto_door_mbr_sub( mbr, x1, y1 ) )
+		return TRUE;
+	if( chk_auto_door_mbr_sub( mbr, x2, y2 ) )
+		return TRUE;
+
+	return FALSE;
+}
+
+/**/
+
+bool_t	chk_auto_door_mbr_sub( mbr_t *mbr, long x, long y )
 {
 	dun_t	*dun = get_dun();
 
@@ -1806,17 +1939,15 @@ bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 )
 
 	if( !chk_flg( mbr->flg_chr, FLG_CHR_AUTO_DOOR ) )
 		return FALSE;
+	if( !clip_pos( x, y ) )
+		return FALSE;
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_DOOR_CLOSE )
+		return FALSE;
+	if( chk_flg( dun->map.obj.flg[y][x], FLG_MAP_OBJ_LOOK_WALL ) )
+		return FALSE;
 
-	if( dun->map.obj.mjr[y1][x1] == FACE_MJR_DOOR_CLOSE ){
-		act_chr_auto_door( mbr, x1, y1 );
-		return TRUE;
-	}
-	if( dun->map.obj.mjr[y2][x2] == FACE_MJR_DOOR_CLOSE ){
-		act_chr_auto_door( mbr, x2, y2 );
-		return TRUE;
-	}
-
-	return FALSE;
+	act_chr_auto_door( mbr, x, y );
+	return TRUE;
 }
 
 /**/
@@ -1907,7 +2038,7 @@ void	mbr_peep_door( mbr_t *mbr, long dr_n )
 
 			x = dun->door[dr_n].x + dx;
 			y = dun->door[dr_n].y + dy;
-			dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+			dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_LOOK;
 		}
 	}
 
@@ -1926,7 +2057,7 @@ void	mbr_peep_door( mbr_t *mbr, long dr_n )
 
 			x = dun->door[dr_n].x + dx;
 			y = dun->door[dr_n].y + dy;
-			dun->map.obj.flg[y][x] &= ~FLG_MAP_OBJ_PASS;
+			dun->map.obj.flg[y][x] &= ~(FLG_MAP_OBJ_LOOK);
 		}
 	}
 
@@ -2340,6 +2471,106 @@ void	exp_party( long exp, bool_t flg_set_max, bool_t flg_draw )
 
 /**/
 
+long	get_mbr_race_exp( mbr_t *mbr, long exp, abl_kind_t abl )
+{
+	rate_t	rate;
+
+	if( mbr == NULL )
+		return exp;
+	if( !is_mbr( mbr ) )
+		return exp;
+
+	rate = _100_PERCENT;
+
+	switch( mbr->race.main ){
+	case MAIN_RACE_HUMAN:
+		break;
+	case MAIN_RACE_HALF_ELF:
+		if( abl == ABL_KIND_STR )
+			rate -= 5;
+		if( abl == ABL_KIND_CHA )
+			rate += 5;
+		break;
+	case MAIN_RACE_ELF:
+		if( abl == ABL_KIND_HP )
+			rate -= 5;
+		if( abl == ABL_KIND_STR )
+			rate -= 5;
+		if( abl == ABL_KIND_INT )
+			rate += 5;
+		if( abl == ABL_KIND_CHA )
+			rate += 5;
+		break;
+	case MAIN_RACE_DWARF:
+		if( abl == ABL_KIND_HP )
+			rate += 5;
+		if( abl == ABL_KIND_STR )
+			rate += 5;
+		if( abl == ABL_KIND_INT )
+			rate -= 5;
+		if( abl == ABL_KIND_CHA )
+			rate -= 5;
+		break;
+	case MAIN_RACE_VIVID:
+		if( abl == ABL_KIND_HP )
+			rate -= 5;
+		if( abl == ABL_KIND_MP )
+			rate -= 5;
+		if( abl == ABL_KIND_DEX )
+			rate += 5;
+		if( abl == ABL_KIND_AGI )
+			rate += 5;
+		break;
+	case MAIN_RACE_MAX_N:
+		break;
+	}
+
+	switch( mbr->race.sub ){
+	case SUB_RACE_NULL:
+		break;
+	case SUB_RACE_CAT:
+		if( abl == ABL_KIND_AGI )
+			rate += 5;
+		break;
+	case SUB_RACE_DOG:
+		if( abl == ABL_KIND_INT )
+			rate += 5;
+		break;
+	case SUB_RACE_MOUSE:
+		if( abl == ABL_KIND_WIS )
+			rate += 5;
+		break;
+	case SUB_RACE_RABBIT:
+		if( abl == ABL_KIND_CHA )
+			rate += 5;
+		break;
+	case SUB_RACE_MONKEY:
+		if( abl == ABL_KIND_DEX )
+			rate += 5;
+		break;
+	case SUB_RACE_PIG:
+		if( abl == ABL_KIND_HP )
+			rate += 5;
+		break;
+	case SUB_RACE_BIRD:
+		if( abl == ABL_KIND_MP )
+			rate += 5;
+		break;
+	case SUB_RACE_LIZARD:
+		if( abl == ABL_KIND_STR )
+			rate += 5;
+		break;
+	case SUB_RACE_MAX_N:
+		break;
+	}
+
+	exp = (exp * rate) / _100_PERCENT;
+
+	return exp;
+}
+
+/**/
+
 void	remove_mbr( mbr_t *mbr )
 {
 	long	i;
@@ -3077,6 +3308,7 @@ bool_t	remove_class( long class_n )
 bool_t	cmp_class( class_t *org, class_t *dst )
 {
 	long	abl;
+	long	i;
 
 	if( strncmp( org->name, dst->name, CLASS_NAME_MAX_LEN ) != 0 )
 		return FALSE;
@@ -3085,6 +3317,10 @@ bool_t	cmp_class( class_t *org, class_t *dst )
 		if( org->abl_rate[abl] != dst->abl_rate[abl] )
 			return FALSE;
 
+	for( i = 0; i < SKILL_MAX_N; i++ )
+		if( org->skill[i] != dst->skill[i] )
+			return FALSE;
+
 	return TRUE;
 }
 
