@@ -78,6 +78,8 @@ void	counter_magic(
 );
 bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item );
 bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt );
+fx_kind_t	cv_spell_to_fx( spell_kind_t spell );
+flg_stat_t	cv_spell_to_stat( spell_kind_t spell );
 bool_t	chk_bar_limit( chr_t *chr );
 bool_t	chk_bar_limit_lev( chr_t *chr );
 bool_t	chk_can_chr_cast_stat( chr_t *chr );
